<?php

/* Copyright (C) 2001-2007 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2005      Brice Davoleau       <brice.davoleau@gmail.com>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@capnetworks.com>
 * Copyright (C) 2006-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2007      Patrick Raguin  		<patrick.raguin@gmail.com>
 * Copyright (C) 2010      Juanjo Menent        <jmenent@2byte.es>
 * Copyright (C) 2015      Marcos García        <marcosgdf@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *  \file       htdocs/societe/agenda.php
 *  \ingroup    societe
 *  \brief      Page of third party events
 */
$res = 0;
if (!$res && file_exists("../main.inc.php"))
    $res = @include("../main.inc.php");
if (!$res && file_exists("../../main.inc.php"))
    $res = @include("../../main.inc.php");
if (!$res && file_exists("../../../main.inc.php"))
    $res = @include("../../../main.inc.php");
if (!$res && file_exists("../../../../main.inc.php"))
    $res = @include("../../../../main.inc.php");
if (!$res && file_exists("../../../dolibarr/htdocs/main.inc.php"))
    $res = @include("../../../dolibarr/htdocs/main.inc.php");     // Used on dev env only
if (!$res && file_exists("../../../../dolibarr/htdocs/main.inc.php"))
    $res = @include("../../../../dolibarr/htdocs/main.inc.php");   // Used on dev env only
if (!$res && file_exists("../../../../../dolibarr/htdocs/main.inc.php"))
    $res = @include("../../../../../dolibarr/htdocs/main.inc.php");   // Used on dev env only
if (!$res)
    die("Include of main fails");
require_once DOL_DOCUMENT_ROOT . '/contact/class/contact.class.php';

require_once DOL_DOCUMENT_ROOT . '/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/functions.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/functions2.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/company.lib.php';

if (!empty($conf->projet->enabled)) {
    require_once DOL_DOCUMENT_ROOT . '/projet/class/project.class.php';
    require_once DOL_DOCUMENT_ROOT . '/core/class/html.formprojet.class.php';
}

$langs->load("companies");
$langs->load("dolimapmail@dolimapmail");
$langs->load('orders');
$langs->load('propal');
$langs->load('sendings');
$langs->load('companies');
$langs->load('bills');
$langs->load('propal');
$langs->load('deliveries');
$langs->load('sendings');
$langs->load('products');
$langs->load('other');

// Security check
$id = GETPOST('id', 'int');
$source = GETPOST('source');


$form = new Form($db);
if (!empty($conf->projet->enabled))
    $formproject = new FormProjets($db);


switch ($source) {
    case 'thirdparty':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'societe', $id, '&societe');
        require_once DOL_DOCUMENT_ROOT . '/core/lib/company.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/societe/class/societe.class.php';
        $object = new Societe($db);
        $result = $object->fetch($socid);
        $head = societe_prepare_head($object);
        $title = $langs->trans("thirparty");
        $picto = 'company';
        $paramid = 'socid';
        $fieldid = 'rowid';
        $fieldref = 'nom';
        $linkback = '';
        $shownav = ($user->societe_id ? 0 : 1);
        $morehtmlref = '';
        break;
    case 'customer_propal':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'propal', $id);
        require_once DOL_DOCUMENT_ROOT . '/core/lib/propal.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/comm/propal/class/propal.class.php';
        $object = new Propal($db);
        $result = $object->fetch($id);
        $result = $object->fetch_thirdparty();
        $head = propal_prepare_head($object);
        $title = $langs->trans("Proposal");
        $picto = 'propal';
        $paramid = 'ref';
        $fieldid = 'ref';
        $fieldref = 'ref';
        $linkback = '<a href="' . DOL_URL_ROOT . '/comm/propal/list.php?restore_lastsearch_values=1' . (!empty($socid) ? '&socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $shownav = ($user->societe_id ? 0 : 1);
        $morehtmlref = '<div class="refidno">';
        // Ref customer
        $morehtmlref.=$form->editfieldkey("RefCustomer", 'ref_client',
                $object->ref_client, $object, $user->rights->propal->creer,
                'string', '', 0, 1);
        $morehtmlref.=$form->editfieldval("RefCustomer", 'ref_client',
                $object->ref_client, $object, $user->rights->propal->creer,
                'string', '', null, null, '', 1);
        // Thirdparty
        $morehtmlref.='<br>' . $langs->trans('ThirdParty') . ' : ' . $object->thirdparty->getNomUrl(1);
        if (empty($conf->global->MAIN_DISABLE_OTHER_LINK) && $object->thirdparty->id
                > 0)
            $morehtmlref.=' (<a href="' . DOL_URL_ROOT . '/comm/propal/list.php?socid=' . $object->thirdparty->id . '">' . $langs->trans("OtherProposals") . '</a>)';
        $morehtmlref.='</div>';
        break;
    case 'customer_order':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'commande', $id);
        require_once DOL_DOCUMENT_ROOT . '/core/lib/order.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/commande/class/commande.class.php';
        $object = new Commande($db);
        $result = $object->fetch($id);
        $result = $object->fetch_thirdparty();
        $head = commande_prepare_head($object);
        $title = $langs->trans("CustomerOrder");
        $picto = 'order';
        $paramid = 'ref';
        $fieldid = 'ref';
        $fieldref = 'ref';
        $linkback = '<a href="' . DOL_URL_ROOT . '/commande/list.php?restore_lastsearch_values=1' . (!empty($socid) ? '&socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $shownav = ($user->societe_id ? 0 : 1);
        $morehtmlref = '<div class="refidno">';
        // Ref customer
        $morehtmlref.=$form->editfieldkey("RefCustomer", 'ref_client',
                $object->ref_client, $object, $user->rights->commande->creer,
                'string', '', 0, 1);
        $morehtmlref.=$form->editfieldval("RefCustomer", 'ref_client',
                $object->ref_client, $object, $user->rights->commande->creer,
                'string', '', null, null, '', 1);
        // Thirdparty
        $morehtmlref.='<br>' . $langs->trans('ThirdParty') . ' : ' . $object->thirdparty->getNomUrl(1);
        if (empty($conf->global->MAIN_DISABLE_OTHER_LINK) && $object->thirdparty->id
                > 0)
            $morehtmlref.=' (<a href="' . DOL_URL_ROOT . '/commande/list.php?socid=' . $object->thirdparty->id . '">' . $langs->trans("OtherOrders") . '</a>)';
        $morehtmlref.='</div>';
        break;
    case 'customer_invoice':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'facture', $id, '', '', 'fk_soc',
                $fieldid);
        require_once DOL_DOCUMENT_ROOT . '/core/lib/invoice.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/compta/facture/class/facture.class.php';
        $object = new Facture($db);
        $result = $object->fetch($id);
        $result = $object->fetch_thirdparty();
        $head = facture_prepare_head($object);
        $title = $langs->trans("InvoiceCustomer");
        $picto = 'bill';
        $paramid = 'ref';
        $fieldid = 'ref';
        $fieldref = 'ref';
        $linkback = '<a href="' . DOL_URL_ROOT . '/compta/facture/list.php?restore_lastsearch_values=1' . (!empty($socid) ? '&socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $shownav = ($user->societe_id ? 0 : 1);
        $morehtmlref = '<div class="refidno">';
        // Ref customer
        $morehtmlref.=$form->editfieldkey("RefCustomer", 'ref_client',
                $object->ref_client, $object, $user->rights->facture->creer,
                'string', '', 0, 1);
        $morehtmlref.=$form->editfieldval("RefCustomer", 'ref_client',
                $object->ref_client, $object, $user->rights->facture->creer,
                'string', '', null, null, '', 1);
        // Thirdparty
        $morehtmlref.='<br>' . $langs->trans('ThirdParty') . ' : ' . $object->thirdparty->getNomUrl(1);
        if (empty($conf->global->MAIN_DISABLE_OTHER_LINK) && $object->thirdparty->id
                > 0)
            $morehtmlref.=' (<a href="' . DOL_URL_ROOT . '/compta/facture/list.php?socid=' . $object->thirdparty->id . '">' . $langs->trans("OtherBills") . '</a>)';
        $morehtmlref.='</div>';
        break;
    case 'supplier_proposal':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'supplier_proposal', $id);
        require_once DOL_DOCUMENT_ROOT . '/core/lib/supplier_proposal.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/supplier_proposal/class/supplier_proposal.class.php';
        $object = new SupplierProposal($db);
        $result = $object->fetch($id);
        $result = $object->fetch_thirdparty();
        $head = supplier_proposal_prepare_head($object);
        $title = $langs->trans("CommRequest");
        $picto = 'supplier_proposal';
        $paramid = 'ref';
        $fieldid = 'ref';
        $fieldref = 'ref';
        $shownav = ($user->societe_id ? 0 : 1);
        $linkback = '<a href="' . DOL_URL_ROOT . '/supplier_proposal/list.php' . (!empty($socid) ? '?socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $morehtmlref = '<div class="refidno">';
        // Ref supplier
        //$morehtmlref.=$form->editfieldkey("RefSupplier", 'ref_supplier', $object->ref_supplier, $object, $user->rights->fournisseur->commande->creer, 'string', '', 0, 1);
        //$morehtmlref.=$form->editfieldval("RefSupplier", 'ref_supplier', $object->ref_supplier, $object, $user->rights->fournisseur->commande->creer, 'string', '', null, null, '', 1);
        // Thirdparty
        $morehtmlref.=$langs->trans('ThirdParty') . ' : ' . $object->thirdparty->getNomUrl(1);
        $morehtmlref.='</div>';

        break;
    case 'supplier_order':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'fournisseur', $id, '', 'commande');
        require_once DOL_DOCUMENT_ROOT . '/core/lib/fourn.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/fourn/class/fournisseur.commande.class.php';
        $object = new CommandeFournisseur($db);
        $result = $object->fetch($id);
        $result = $object->fetch_thirdparty();
        $head = ordersupplier_prepare_head($object);
        $title = $langs->trans("SupplierOrder");
        $picto = 'order';
        $paramid = 'ref';
        $fieldid = 'ref';
        $fieldref = 'ref';
        $shownav = ($user->societe_id ? 0 : 1);
        $linkback = '<a href="' . DOL_URL_ROOT . '/fourn/commande/list.php' . (!empty($socid) ? '?socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $morehtmlref = '<div class="refidno">';
        // Ref supplier
        $morehtmlref.=$form->editfieldkey("RefSupplier", 'ref_supplier',
                $object->ref_supplier, $object,
                $user->rights->fournisseur->commande->creer, 'string', '', 0, 1);
        $morehtmlref.=$form->editfieldval("RefSupplier", 'ref_supplier',
                $object->ref_supplier, $object,
                $user->rights->fournisseur->commande->creer, 'string', '', null,
                null, '', 1);
        // Thirdparty
        $morehtmlref.='<br>' . $langs->trans('ThirdParty') . ' : ' . $object->thirdparty->getNomUrl(1);
        $morehtmlref.='</div>';

        break;
    case 'supplier_invoice':
        if ($user->societe_id)
            $socid = $user->societe_id;
        $result = restrictedArea($user, 'fournisseur', $id, 'facture_fourn',
                'facture');
        require_once DOL_DOCUMENT_ROOT . '/core/lib/fourn.lib.php';
        require_once DOL_DOCUMENT_ROOT . '/fourn/class/fournisseur.facture.class.php';
        $object = new FactureFournisseur($db);
        $result = $object->fetch($id);
        $result = $object->fetch_thirdparty();
        $head = facturefourn_prepare_head($object);
        $title = $langs->trans("SupplierInvoice");
        $picto = 'bill';
        $paramid = 'ref';
        $fieldid = 'ref';
        $fieldref = 'ref';
        $shownav = ($user->societe_id ? 0 : 1);
        $linkback = '<a href="' . DOL_URL_ROOT . '/fourn/facture/list.php' . (!empty($socid) ? '?socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $morehtmlref = '<div class="refidno">';
        // Ref supplier
        $morehtmlref.=$form->editfieldkey("RefSupplier", 'ref_supplier',
                $object->ref_supplier, $object,
                $user->rights->fournisseur->facture->creer, 'string', '', 0, 1);
        $morehtmlref.=$form->editfieldval("RefSupplier", 'ref_supplier',
                $object->ref_supplier, $object,
                $user->rights->fournisseur->facture->creer, 'string', '', null,
                null, '', 1);
        // Thirdparty
        $morehtmlref.='<br>' . $langs->trans('ThirdParty') . ' : ' . $object->thirdparty->getNomUrl(1);
        $morehtmlref.='</div>';

        break;
    default:
        print $source;
        accessforbidden();
        $source = 'unknown';
}

// Initialize technical object to manage hooks of thirdparties. Note that conf->hooks_modules contains array array
$hookmanager->initHooks(array('linkedmaillistthirdparty'));


/*
 * 	Actions
 */

$parameters = array('id' => $id);
$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action);    // Note that $action and $object may have been modified by some hooks
if
 ($reshook < 0)
    setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');



/*
 * 	View
 */

$contactstatic = new Contact($db);

if ($id) {

//    $title = $langs->trans("Agenda");
    if (!empty($conf->global->MAIN_HTML_TITLE) && preg_match(
                    '/thirdpartynameonly/', $conf->global->MAIN_HTML_TITLE) &&
            $object->name)
        $title = $object->name . " - " . $title;
    llxHeader('', $title);

    if (!empty($conf->notification
                    ->enabled))
        $langs->load("mails");

    dol_fiche_head($head, 'linkedmaillist', $title, 0, $picto);

    dol_banner_tab($object, $paramid, $linkback, $shownav, $fieldid, $fieldref,
            $morehtmlref);

    dol_fiche_end();

    if (!empty($conf->agenda->enabled) && (!empty($user->rights->agenda->myactions->read
            ) || !empty($user->rights->agenda->allactions->read))) {

        // List of actions on element
        include_once DOL_DOCUMENT_ROOT . '/core/class/html.formactions.class.php';
        $formactions = new FormActions($db);

        require_once DOL_DOCUMENT_ROOT . '/comm/action/class/actioncomm.class.php';

        $sortfield = 'a.datep';
        $sortorder = 'DESC';
        $typeelement = $object->element;
        $listofactions = getLinkedMails($db, $socid, $object->id, $typeelement);
        
        if (!is_array($listofactions))
            dol_print_error($db, 'FailedToGetActions');
        if ($typeelement == 'invoice' || $typeelement == 'facture')
            $title = $langs->trans('ActionsLinkedListOnBill');
        elseif ($typeelement == 'invoice_supplier' || $typeelement == 'supplier_invoice')
            $title = $langs->trans('ActionsLinkedListOnBill');
        elseif ($typeelement == 'propal')
            $title = $langs->trans('ActionsLinkedListOnPropal');
        elseif ($typeelement == 'supplier_payment')
            $title = $langs->trans('ActionsLinkedListOnSupplierPayment');
        elseif ($typeelement == 'supplier_proposal')
            $title = $langs->trans('ActionsLinkedListOnPropal');
        elseif ($typeelement == 'order' || $typeelement == 'commande')
            $title = $langs->trans('ActionsLinkedListOnOrder');
        elseif ($typeelement == 'order_supplier' || $typeelement == 'supplier_order')
            $title = $langs->trans('ActionsLinkedListOnOrder');
        elseif ($typeelement == 'shipping')
            $title = $langs->trans('ActionsLinkedListOnShipping');
        elseif ($typeelement == 'fichinter')
            $title = $langs->trans('ActionsLinkedListOnFicheInter');
        elseif ($typeelement == 'project')
            $title = $langs->trans('LatestLinkedEvents', $max ? $max : '');
        elseif ($typeelement == 'task')
            $title = $langs->trans('LatestLinkedEvents', $max ? $max : '');
        else
            $title = $langs->trans("Actions");

        $urlbacktopage = $_SERVER['PHP_SELF'] . '?id=' . $object->id . ($moreparambacktopage ? '&' . $moreparambacktopage : '');


        print load_fiche_titre($title, $buttontoaddnewevent, '');

        $page = 0;
        $param = '';

        $total = 0;

        print '<div class="div-table-responsive">';
        print '<table class="noborder' . ($morecss ? ' ' . $morecss : '') . '" width="100%">';
        print '<tr class="liste_titre">';
        print getTitleFieldOfList('Ref', 0, $_SERVER["PHP_SELF"], '', $page,
                        $param, '', $sortfield, $sortorder, '', 1);
        print getTitleFieldOfList('Action', 0, $_SERVER["PHP_SELF"], '', $page,
                        $param, '', $sortfield, $sortorder, '', 1);
        print getTitleFieldOfList('Type', 0, $_SERVER["PHP_SELF"], '', $page,
                        $param, '', $sortfield, $sortorder, '', 1);
        print getTitleFieldOfList('Date', 0, $_SERVER["PHP_SELF"], 'a.datep',
                        $page, $param, 'align="center"', $sortfield, $sortorder,
                        '', 1);
        print getTitleFieldOfList('By', 0, $_SERVER["PHP_SELF"], '', $page,
                        $param, '', $sortfield, $sortorder, '', 1);
        print getTitleFieldOfList('', 0, $_SERVER["PHP_SELF"], '', $page,
                        $param, 'align="right"', $sortfield, $sortorder, '', 1);
        print '</tr>';
        print "\n";

        $num = count($listofactions);
        if ($num || $forceshowtitle) {
//            $buttontoaddnewevent = '<a href="' . DOL_URL_ROOT . '/comm/action/card.php?action=create&datep=' . dol_print_date(dol_now(),
//                            'dayhourlog') . '&origin=' . $typeelement . '&originid=' . $object->id . '&socid=' . $object->socid . '&projectid=' . $object->fk_project . '&backtopage=' . urlencode($urlbacktopage) . '">';
//            $buttontoaddnewevent.= $langs->trans("AddEvent");
//            $buttontoaddnewevent.= '</a>';

            $userstatic = new User($db);

            $cursorevent = 0;

            foreach ($listofactions as $action) {
                if ($max && $cursorevent >= $max)
                    break;

                $ref = $action->getNomUrl(1, -1);
                $label = $action->getNomUrl(0, 38);

                print '<tr class="oddeven">';
                print '<td>' . $ref . '</td>';
                print '<td>' . $label . '</td>';
                print '<td>';
                if (!empty($conf->global->AGENDA_USE_EVENT_TYPE)) {
                    if ($action->type_picto)
                        print img_picto('', $action->type_picto);
                    else {
                        if ($action->type_code == 'AC_RDV')
                            print img_picto('', 'object_group') . ' ';
                        if ($action->type_code == 'AC_TEL')
                            print img_picto('', 'object_phoning') . ' ';
                        if ($action->type_code == 'AC_FAX')
                            print img_picto('', 'object_phoning_fax') . ' ';
                        if ($action->type_code == 'AC_EMAIL')
                            print img_picto('', 'object_email') . ' ';
                    }
                }
                print $action->type;
                print '</td>';
                print '<td align="center">' . dol_print_date($action->datep,
                                'dayhour');
                if ($action->datef) {
                    $tmpa = dol_getdate($action->datep);
                    $tmpb = dol_getdate($action->datef);
                    if ($tmpa['mday'] == $tmpb['mday'] && $tmpa['mon'] == $tmpb['mon']
                            && $tmpa['year'] == $tmpb['year']) {
                        if ($tmpa['hours'] != $tmpb['hours'] || $tmpa['minutes']
                                != $tmpb['minutes'] && $tmpa['seconds'] != $tmpb['seconds'])
                            print '-' . dol_print_date($action->datef, 'hour');
                    }
                    else
                        print '-' . dol_print_date($action->datef, 'dayhour');
                }
                print '</td>';
                print '<td>';
                if (!empty($action->userownerid)) {
                    $userstatic->fetch($action->userownerid); // TODO Introduce a cache on users fetched
                    print $userstatic->getNomUrl(-1, '', 0, 0, 16, 0, '', '');
                }
                print '</td>';
                print '<td align="right">';
                if (!empty($action->author->id)) {
                    print $action->getLibStatut(3);
                }
                print '</td>';
                print '</tr>';

                $cursorevent++;
            }

            if ($max && $num > $max) {
                print '<tr class="oddeven"><td colspan="6">' . $langs->trans("More") . '...</td></tr>';
            }
        }

        print '</table>';
        print '</div>';
    }
}


llxFooter();

$db->close();
